package Clang::TypeKind;
$Clang::TypeKind::VERSION = '0.07';
use strict;
use warnings;

=head1 NAME

Clang::TypeKind - Clang type kind class

=head1 VERSION

version 0.07

=head1 DESCRIPTION

A C<Clang::TypeKind> describes the kind of a given type.

=head1 METHODS/SUBROUTINES

=head2 spelling( )

Retrieve the name of the given type kind.

=head1 AUTHOR

Alessandro Ghedini <alexbio@cpan.org>

=head1 LICENSE AND COPYRIGHT

Copyright 2012 Alessandro Ghedini.

This program is free software; you can redistribute it and/or modify it
under the terms of either: the GNU General Public License as published
by the Free Software Foundation; or the Artistic License.

See http://dev.perl.org/licenses/ for more information.

=cut

1; # End of Clang::TypeKind
